@@ -120,7 +120,6 @@
 /* Stuff that used to be globally declared in plat.h but is now extern there
    and declared here instead. */
 int          dopause = 1;  /* system is paused */
-atomic_flag  doresize; /* screen resize requested */
 volatile int is_quit;  /* system exit requested */
 uint64_t     timer_freq;
 char         emu_version[200]; /* version ID string */
@@ -144,10 +143,12 @@ int confirm_exit_cmdl = 1; /* (O) do not ask for confirmation on quit if set to
 uint64_t unique_id   = 0;
 uint64_t source_hwnd = 0;
 #endif
-char       rom_path[1024] = { '\0' };     /* (O) full path to ROMs */
-rom_path_t rom_paths      = { "", NULL }; /* (O) full paths to ROMs */
-char       log_path[1024] = { '\0' };     /* (O) full path of logfile */
-char       vm_name[1024]  = { '\0' };     /* (O) display name of the VM */
+char       rom_path[1024]   = { '\0' };     /* (O) full path to ROMs */
+rom_path_t rom_paths        = { "", NULL }; /* (O) full paths to ROMs */
+char       asset_path[1024] = { '\0' };     /* (O) full path to assets */
+rom_path_t asset_paths      = { "", NULL }; /* (O) full paths to assets */
+char       log_path[1024]   = { '\0' };     /* (O) full path of logfile */
+char       vm_name[1024]    = { '\0' };     /* (O) display name of the VM */
 int      do_nothing                             = 0;
 int      dump_missing                           = 0;
 int      clear_cmos                             = 0;
@@ -171,6 +172,7 @@ int      vid_api                                = 0;              /* (C) video r
 int      vid_cga_contrast                       = 0;              /* (C) video */
 int      video_fullscreen                       = 0;              /* (C) video */
 int      video_fullscreen_scale                 = 0;              /* (C) video */
+int      fullscreen_ui_visible                  = 0;              /* (C) video */
 int      enable_overscan                        = 0;              /* (C) video */
 int      force_43                               = 0;              /* (C) video */
 int      video_filter_method                    = 1;              /* (C) video */
@@ -262,6 +264,11 @@ struct accelKey def_acc_keys[NUM_ACCELS] = {
         .desc="Toggle fullscreen",
         .seq="Ctrl+Alt+PgUp"
     },
+    {
+        .name="toggle_ui_fullscreen",
+        .desc="Toggle UI in fullscreen",
+        .seq="Ctrl+Alt+PgDown"
+    },
     {
         .name="screenshot",
         .desc="Screenshot",
@@ -286,6 +293,11 @@ struct accelKey def_acc_keys[NUM_ACCELS] = {
         .name="mute",
         .desc="Toggle mute",
         .seq="Ctrl+Alt+M"
+    },
+    {
+        .name="force_interpretation",
+        .desc="Force interpretation",
+        .seq="Ctrl+Alt+I"
     }
 };
 
@@ -331,8 +343,8 @@ __thread int is_cpu_thread = 0;
 
 static wchar_t mouse_msg[3][200];
 
-static volatile atomic_int do_pause_ack = 0;
-static volatile atomic_int pause_ack = 0;
+static ATOMIC_INT do_pause_ack = 0;
+static ATOMIC_INT pause_ack = 0;
 
 #define LOG_SIZE_BUFFER 8192            /* Log size buffer */
 
@@ -657,6 +669,7 @@ pc_show_usage(char *s)
             "\n%sUsage: 86box [options] [cfg-file]\n\n"
             "Valid options are:\n\n"
             "-? or --help\t\t\t- show this information\n"
+            "-A or --assetpath path\t\t- set 'path' to be asset path\n"
 #ifdef SHOW_EXTRA_PARAMS
             "-C or --config path\t\t- set 'path' to be config file\n"
 #endif
@@ -727,6 +740,7 @@ pc_init(int argc, char *argv[])
 {
     char            *ppath = NULL;
     char            *rpath = NULL;
+    char            *apath = NULL;
     char            *cfg = NULL;
     char            *global = NULL;
     char            *p;
@@ -753,8 +767,10 @@ pc_init(int argc, char *argv[])
     p  = path_get_filename(exe_path);
     *p = '\0';
 #if defined(__APPLE__)
+    char contents_path[2048] = {0};
     c = strlen(exe_path);
     if ((c >= 16) && !strcmp(&exe_path[c - 16], "/Contents/MacOS/")) {
+        strncpy(contents_path, exe_path, c - 7);
         exe_path[c - 16] = '\0';
         p                = path_get_filename(exe_path);
         *p               = '\0';
@@ -793,6 +809,7 @@ pc_init(int argc, char *argv[])
      */
     plat_getcwd(usr_path, sizeof(usr_path) - 1);
     plat_getcwd(rom_path, sizeof(rom_path) - 1);
+    plat_getcwd(asset_path, sizeof(asset_path) - 1);
 
     for (c = 1; c < argc; c++) {
         if (argv[c][0] != '-')
@@ -846,6 +863,12 @@ usage:
 
             rpath = argv[++c];
             rom_add_path(rpath);
+        } else if (!strcasecmp(argv[c], "--assetpath") || !strcasecmp(argv[c], "-A")) {
+            if ((c + 1) == argc)
+                goto usage;
+
+            apath = argv[++c];
+            asset_add_path(apath);
         } else if (!strcasecmp(argv[c], "--config") || !strcasecmp(argv[c], "-C")) {
             if ((c + 1) == argc || plat_dir_check(argv[c + 1]))
                 goto usage;
@@ -969,6 +992,7 @@ usage:
 
     path_slash(usr_path);
     path_slash(rom_path);
+    path_slash(asset_path);
 
     /*
      * If the user provided a path for files, use that
@@ -1009,6 +1033,33 @@ usage:
 
     plat_init_rom_paths();
 
+    // Add the VM-local asset path.
+    path_append_filename(temp, usr_path, "assets");
+    asset_add_path(temp);
+
+    // Add the standard asset path in the same directory as the executable.
+    path_append_filename(temp, exe_path, "assets");
+    asset_add_path(temp);
+
+#if defined(__APPLE__)
+    // Add the standard asset path within the app bundle.
+    if (contents_path[0] != '\0') {
+        path_append_filename(temp, contents_path, "Resources/assets");
+        asset_add_path(temp);
+    }
+#elif !defined(_WIN32)
+    // Add the standard asset paths within the AppImage.
+    p = getenv("APPDIR");
+    if (p && (p[0] != '\0')) {
+        path_append_filename(temp, p, "usr/local/share/" EMU_NAME "/assets");
+        asset_add_path(temp);
+        path_append_filename(temp, p, "usr/share/" EMU_NAME "/assets");
+        asset_add_path(temp);
+    }
+#endif
+
+    plat_init_asset_paths();
+
     /*
      * If the user provided a path for ROMs, use that
      * instead of the current working directory. We do
@@ -1039,6 +1090,36 @@ usage:
     } else
         rom_path[0] = '\0';
 
+    /*
+     * If the user provided a path for ROMs, use that
+     * instead of the current working directory. We do
+     * make sure that if that was a relative path, we
+     * make it absolute.
+     */
+    if (apath != NULL) {
+        if (!path_abs(apath)) {
+            /*
+             * This looks like a relative path.
+             *
+             * Add it to the current working directory
+             * to convert it (back) to an absolute path.
+             */
+            strcat(asset_path, apath);
+        } else {
+            /*
+             * The user-provided path seems like an
+             * absolute path, so just use that.
+             */
+            strcpy(asset_path, apath);
+        }
+
+        /* If the specified path does not yet exist,
+           create it. */
+        if (!plat_dir_check(asset_path))
+            plat_dir_create(asset_path);
+    } else
+        asset_path[0] = '\0';
+
     /* Grab the name of the configuration file. */
     if (cfg == NULL)
         cfg = CONFIG_FILE;
@@ -1076,6 +1157,8 @@ usage:
     path_slash(usr_path);
     if (rom_path[0] != '\0')
         path_slash(rom_path);
+    if (asset_path[0] != '\0')
+        path_slash(asset_path);
 
     /* At this point, we can safely create the full path name. */
     path_append_filename(cfg_path, usr_path, p);
@@ -1083,7 +1166,10 @@ usage:
     /* Build the global configuration file path. */
     if (global == NULL) {
         plat_get_global_config_dir(global_cfg_path, sizeof(global_cfg_path));
-        path_append_filename(global_cfg_path, global_cfg_path, GLOBAL_CONFIG_FILE);
+        // avoid strcpy global_cfg_path over itself (valgrind says it's bad...)
+        // path_append_filename(global_cfg_path, global_cfg_path, GLOBAL_CONFIG_FILE);
+        path_slash(global_cfg_path);
+        strcat(global_cfg_path, GLOBAL_CONFIG_FILE);
     } else {
         strncpy(global_cfg_path, global, sizeof(global_cfg_path) - 1);
     }
@@ -1174,6 +1260,10 @@ usage:
             pclog("# ROM path: %s\n", rom_path->path);
         }
 
+        for (rom_path_t *asset_path = &asset_paths; asset_path != NULL; asset_path = asset_path->next) {
+            pclog("# Asset path: %s\n", asset_path->path);
+        }
+
         /*
          * We are about to read the configuration file, which MAY
          * put data into global variables (the hard- and floppy
@@ -1720,6 +1810,7 @@ pc_reset_hard_init(void)
 void
 update_mouse_msg(void)
 {
+#ifdef USE_SDL_UI
     wchar_t  wcpufamily[2048];
     wchar_t  wcpu[2048];
     wchar_t  wmachine[2048];
@@ -1736,21 +1827,20 @@ update_mouse_msg(void)
     if (wcp) /* remove parentheses */
         *(wcp - 1) = L'\0';
     mbstowcs(wcpu, cpu_s->name, strlen(cpu_s->name) + 1);
-#ifdef _WIN32
-    swprintf(mouse_msg[0], sizeof_w(mouse_msg[0]), L"%%i.%%i%%%% - %ls",
-             plat_get_string(STRING_MOUSE_CAPTURE));
-    swprintf(mouse_msg[1], sizeof_w(mouse_msg[1]), L"%%i.%%i%%%% - %ls",
-             (mouse_get_buttons() > 2) ? plat_get_string(STRING_MOUSE_RELEASE) : plat_get_string(STRING_MOUSE_RELEASE_MMB));
-    wcsncpy(mouse_msg[2], L"%i.%i%%", sizeof_w(mouse_msg[2]));
-#else
-    swprintf(mouse_msg[0], sizeof_w(mouse_msg[0]), L"%ls v%ls - %%i.%%i%%%% - %ls - %ls/%ls - %ls",
+    swprintf(mouse_msg[0], sizeof_w(mouse_msg[0]), L"%ls v%ls - %%i%%%% - %ls - %ls/%ls - %ls",
              EMU_NAME_W, EMU_VERSION_FULL_W, wmachine, wcpufamily, wcpu,
              plat_get_string(STRING_MOUSE_CAPTURE));
-    swprintf(mouse_msg[1], sizeof_w(mouse_msg[1]), L"%ls v%ls - %%i.%%i%%%% - %ls - %ls/%ls - %ls",
+    swprintf(mouse_msg[1], sizeof_w(mouse_msg[1]), L"%ls v%ls - %%i%%%% - %ls - %ls/%ls - %ls",
              EMU_NAME_W, EMU_VERSION_FULL_W, wmachine, wcpufamily, wcpu,
              (mouse_get_buttons() > 2) ? plat_get_string(STRING_MOUSE_RELEASE) : plat_get_string(STRING_MOUSE_RELEASE_MMB));
-    swprintf(mouse_msg[2], sizeof_w(mouse_msg[2]), L"%ls v%ls - %%i.%%i%%%% - %ls - %ls/%ls",
+    swprintf(mouse_msg[2], sizeof_w(mouse_msg[2]), L"%ls v%ls - %%i%%%% - %ls - %ls/%ls",
              EMU_NAME_W, EMU_VERSION_FULL_W, wmachine, wcpufamily, wcpu);
+#else
+    swprintf(mouse_msg[0], sizeof_w(mouse_msg[0]), L"%%i%%%% - %ls",
+             plat_get_string(STRING_MOUSE_CAPTURE));
+    swprintf(mouse_msg[1], sizeof_w(mouse_msg[1]), L"%%i%%%% - %ls",
+             (mouse_get_buttons() > 2) ? plat_get_string(STRING_MOUSE_RELEASE) : plat_get_string(STRING_MOUSE_RELEASE_MMB));
+    wcsncpy(mouse_msg[2], L"%i%%", sizeof_w(mouse_msg[2]));
 #endif
 }
 
@@ -1832,9 +1922,9 @@ _ui_window_title(void *s)
 void
 ack_pause(void)
 {
-    if (atomic_load(&do_pause_ack)) {
-        atomic_store(&do_pause_ack, 0);
-        atomic_store(&pause_ack, 1);
+    if (ATOMIC_LOAD(do_pause_ack)) {
+        ATOMIC_STORE(do_pause_ack, 0);
+        ATOMIC_STORE(pause_ack, 1);
     }
 }
 
@@ -1884,7 +1974,7 @@ pc_run(void)
         else
             fps = ((fps + 20) / 50) * 50;
 #endif
-        swprintf(temp, sizeof_w(temp), mouse_msg[mouse_msg_idx], fps / (force_10ms ? 1 : 10), force_10ms ? 0 : (fps % 10));
+        swprintf(temp, sizeof_w(temp), mouse_msg[mouse_msg_idx], fps / (force_10ms ? 1 : 10));
 #ifdef __APPLE__
         /* Needed due to modifying the UI on the non-main thread is a big no-no. */
         dispatch_async_f(dispatch_get_main_queue(), wcsdup((const wchar_t *) temp), _ui_window_title);
@@ -2048,17 +2138,6 @@ set_screen_size_natural(void)
         set_screen_size(monitors[i].mon_unscaled_size_x, monitors[i].mon_unscaled_size_y);
 }
 
-int
-get_actual_size_x(void)
-{
-    return (unscaled_size_x);
-}
-
-int
-get_actual_size_y(void)
-{
-    return (efscrnsz_y);
-}
 
 void
 do_pause(int p)
@@ -2069,10 +2148,10 @@ do_pause(int p)
         do_pause_ack = p;
     dopause = !!p;
     if ((p == 1) && !old_p) {
-        while (!atomic_load(&pause_ack))
+        while (!ATOMIC_LOAD(pause_ack))
             ;
     }
-    atomic_store(&pause_ack, 0);
+    ATOMIC_STORE(pause_ack, 0);
 }
 
 // Helper to find an accelerator key and return it's index in acc_keys
