@@ -92,7 +92,7 @@ typedef struct ram_struct_t {
     int   bank;
 } ram_struct_t;
 
-typedef struct card_mem_t {
+typedef struct mem_page_t {
     int       in_ram;
     uint32_t  virt_addr;
     uint32_t  phys_addr;
@@ -124,10 +124,6 @@ typedef struct scamp_t {
     mem_mapping_t mem_mappings[64]; /* The entire first 1 MB of memory space. */
     mem_page_t    mem_pages[64];
 
-    uint32_t      card_mem_size;
-    uint8_t      *card_mem;
-    mem_page_t    card_pages[4];
-
     port_92_t    *port_92;
 } scamp_t;
 
@@ -1180,14 +1176,6 @@ scamp_init(UNUSED(const device_t *info))
         }
     }
 
-    dev->card_mem = NULL;
-
-    for (uint8_t i = 0; i < 4; i++) {
-        dev->card_pages[i].virt_addr = i * EMS_PGSIZE;
-        dev->card_pages[i].phys_addr = dev->card_pages[i].virt_addr;
-        dev->card_pages[i].mem       = dev->card_mem + dev->card_pages[i].phys_addr;
-    }
-
     dev->port_92 = device_add(&port_92_device);
 
     return dev;
