@@ -559,6 +559,10 @@ codegen_block_start_recompile(codeblock_t *block)
         fatal("Recompile to used block!\n");
 #endif
 
+    if (block->head_mem_block) {
+        codegen_allocator_free(block->head_mem_block);
+        block->head_mem_block = NULL;
+    }
     block->head_mem_block = codegen_allocator_allocate(NULL, block_current);
     block->data           = codeblock_allocator_get_ptr(block->head_mem_block);
 
