@@ -20,6 +20,7 @@
 #include "softfloat3e/config.h"
 #include "softfloat3e/fpu_trans.h"
 #include "softfloat3e/specialize.h"
+#include <86box/plat_unused.h>
 
 uint32_t x87_pc_off;
 uint32_t x87_op_off;
@@ -312,7 +313,7 @@ FPU_write_eflags_fpu_compare(int float_relation)
 }
 
 uint16_t
-FPU_exception(uint32_t fetchdat, uint16_t exceptions, int store)
+FPU_exception(UNUSED(uint32_t fetchdat), uint16_t exceptions, int store)
 {
     uint16_t status;
     uint16_t unmasked;
@@ -355,7 +356,10 @@ FPU_exception(uint32_t fetchdat, uint16_t exceptions, int store)
                 nmi = 1;
             }
 #else
-            picint(1 << 13);
+           if (cr0 & 0x20)
+               new_ne = 1;
+           else
+               picint(1 << 13);
 #endif // FPU_8087
         }
         return unmasked;
