@@ -10,8 +10,6 @@
  *
  *          Now passes all the AMIDIAG tests.
  *
- *
- *
  * Authors: Miran Grca, <mgrca8@gmail.com>
  *          Fred N. van Kempen, <decwiz@yahoo.com>
  *
@@ -143,7 +141,7 @@ serial_update_ints(serial_t *dev)
         }
     }
 
-    serial_do_irq(dev, !(dev->iir & 0x01) && ((dev->mctrl & 8) || (dev->type == SERIAL_8250_PCJR)));
+    serial_do_irq(dev, !(dev->iir & 0x01) && ((dev->mctrl & 8) || ((dev->type == SERIAL_8250_PCJR_3F8) || (dev->type == SERIAL_8250_PCJR_2F8))));
 }
 
 static void
@@ -973,15 +971,20 @@ serial_init(const device_t *info)
             serial_setup(dev, COM4_ADDR, COM4_IRQ);
         else if (next_inst == 2)
             serial_setup(dev, COM3_ADDR, COM3_IRQ);
-        else if ((next_inst == 1) || (info->local == SERIAL_8250_PCJR))
+        else if ((next_inst == 1) || (info->local == SERIAL_8250_PCJR_2F8))
             serial_setup(dev, COM2_ADDR, COM2_IRQ);
+        // TODO
+#if 0
+        else if ((next_inst == 1) || (info->local == SERIAL_8250_PCJR_3F8))
+            serial_setup(dev, COM1_ADDR, COM1_IRQ);
+#endif
         else if (next_inst == 0)
             serial_setup(dev, COM1_ADDR, COM1_IRQ);
 
         /* Default to 1200,N,7. */
         dev->dlab = 96;
         dev->fcr  = 0x06;
-        if (info->local == SERIAL_8250_PCJR)
+        if ((info->local == SERIAL_8250_PCJR_3F8) || (info->local == SERIAL_8250_PCJR_2F8))
             dev->clock_src = 1789500.0;
         else
             dev->clock_src = 1843200.0;
@@ -1041,11 +1044,25 @@ const device_t ns8250_device = {
     .config        = NULL
 };
 
-const device_t ns8250_pcjr_device = {
-    .name          = "National Semiconductor 8250(-compatible) UART for PCjr",
-    .internal_name = "ns8250_pcjr",
+const device_t ns8250_pcjr_3f8_device = {
+    .name          = "National Semiconductor 8250(-compatible) UART for PCjr (0x3f8)",
+    .internal_name = "ns8250_pcjr_3f8",
     .flags         = 0,
-    .local         = SERIAL_8250_PCJR,
+    .local         = SERIAL_8250_PCJR_3F8,
+    .init          = serial_init,
+    .close         = serial_close,
+    .reset         = serial_reset,
+    .available     = NULL,
+    .speed_changed = serial_speed_changed,
+    .force_redraw  = NULL,
+    .config        = NULL
+};
+
+const device_t ns8250_pcjr_2f8_device = {
+    .name          = "National Semiconductor 8250(-compatible) UART for PCjr (0x2f8)",
+    .internal_name = "ns8250_pcjr_2f8",
+    .flags         = 0,
+    .local         = SERIAL_8250_PCJR_2F8,
     .init          = serial_init,
     .close         = serial_close,
     .reset         = serial_reset,
