@@ -101,6 +101,9 @@ typedef struct fdd_pending_op_t {
 
 static fdd_pending_op_t fdd_pending[FDD_NUM];
 
+/* BIOS boot status tracking */
+static bios_boot_status_t bios_boot_status = BIOS_BOOT_POST;
+
 char  floppyfns[FDD_NUM][512];
 char *fdd_image_history[FDD_NUM][FLOPPY_IMAGE_HISTORY];
 
@@ -212,9 +215,9 @@ int fdd_do_log = ENABLE_FDD_LOG;
 static void
 fdd_log(const char *fmt, ...)
 {
-    va_list ap, ap_copy;
+    va_list ap;
     char    timebuf[32];
-    char    fullbuf[1056]; // 32 + 1024 bytes for timestamp + message
+    char    fullbuf[1056]; /* 32 + 1024 bytes for timestamp + message */
 
     if (fdd_do_log) {
         uint32_t ticks        = plat_get_ticks();
@@ -224,27 +227,58 @@ fdd_log(const char *fmt, ...)
         snprintf(timebuf, sizeof(timebuf), "[%07u.%03u] ", seconds, milliseconds);
 
         va_start(ap, fmt);
-        va_copy(ap_copy, ap);
-
         strcpy(fullbuf, timebuf);
-        vsnprintf(fullbuf + strlen(timebuf), sizeof(fullbuf) - strlen(timebuf), fmt, ap_copy);
-
-        va_end(ap_copy);
+        vsnprintf(fullbuf + strlen(timebuf), sizeof(fullbuf) - strlen(timebuf), fmt, ap);
         va_end(ap);
 
-        va_start(ap, fmt);
-        va_end(ap);
-
-        char *msg = fullbuf;
-        va_start(ap, fmt);
-        pclog_ex("%s", (va_list) &msg);
-        va_end(ap);
+        pclog("%s", fullbuf);
     }
 }
 #else
 #    define fdd_log(fmt, ...)
 #endif
 
+/*
+ * BIOS boot status functions
+ *
+ * These functions track whether the system is in BIOS POST (Power-On Self Test)
+ * or has transitioned to normal operation. The POST state is set on:
+ *   - System hard reset (fdd_reset)
+ *   - FDC soft reset (fdd_boot_status_reset)
+ *
+ * POST is considered complete when the first floppy read operation occurs,
+ * indicating that BIOS has finished POST and is attempting to boot.
+ */
+bios_boot_status_t
+fdd_get_boot_status(void)
+{
+    return bios_boot_status;
+}
+
+void
+fdd_set_boot_status(bios_boot_status_t status)
+{
+    if (bios_boot_status != status) {
+        fdd_log("BIOS boot status changed: %s -> %s\n",
+                bios_boot_status == BIOS_BOOT_POST ? "POST" : "NORMAL",
+                status == BIOS_BOOT_POST ? "POST" : "NORMAL");
+        bios_boot_status = status;
+    }
+}
+
+void
+fdd_boot_status_reset(void)
+{
+    fdd_log("BIOS boot status reset to POST\n");
+    bios_boot_status = BIOS_BOOT_POST;
+}
+
+int
+fdd_is_post_complete(void)
+{
+    return (bios_boot_status == BIOS_BOOT_NORMAL);
+}
+
 void
 fdd_set_audio_profile(int drive, int profile)
 {
@@ -365,7 +399,7 @@ void
 fdd_seek(int drive, int track_diff)
 {
     fdd_log("fdd_seek(drive=%d, track_diff=%d)\n", drive, track_diff);
-    if (!track_diff)
+    if (track_diff == 0)
         return;
 
     if (fdd_seek_in_progress[drive]) {
@@ -390,10 +424,7 @@ fdd_seek(int drive, int track_diff)
     else {
         /* Trigger appropriate audio for track movements */
         int actual_track_diff = abs(old_track - fdd[drive].track);
-        if (actual_track_diff == 1) {
-            /* Single track movement */
-            fdd_audio_play_single_track_step(drive, old_track, fdd[drive].track);
-        } else if (actual_track_diff > 1) {
+        if (actual_track_diff > 0) {
             /* Multi-track seek */
             fdd_audio_play_multi_track_seek(drive, old_track, fdd[drive].track);
         }
@@ -409,12 +440,19 @@ fdd_seek(int drive, int track_diff)
             timer_add(&(fdd_seek_timer[drive]), fdd_seek_complete_callback, &drives[drive], 0);
         }
 
-        /* Get seek timings from audio profile configuration */
-        double   initial_seek_time = fdd_audio_get_seek_time(drive, 1, actual_track_diff);
-        double   track_seek_time   = fdd_audio_get_seek_time(drive, 0, actual_track_diff);
-        fdd_log("Seek timing for drive %d: initial %.2f ms, per track %.2f ms\n", drive, initial_seek_time, track_seek_time);
-        uint64_t seek_time_us      = (initial_seek_time + (abs(actual_track_diff) * track_seek_time)) * TIMER_USEC;
-        timer_set_delay_u64(&fdd_seek_timer[drive], seek_time_us);
+        /* Determine seek direction - seeking down means moving toward track 0 */
+        int is_seek_down = (fdd[drive].track < old_track);
+
+        /* Get seek timings from audio profile configuration with direction awareness */
+        double   seek_time_us = fdd_audio_get_seek_time(drive, actual_track_diff, is_seek_down);
+        if (seek_time_us < 1) {
+            seek_time_us = DEFAULT_SEEK_TIME_MS * 1000;
+        }
+
+        fdd_log("Seek timing for drive %d: %.2f µs (%s)\n", 
+                drive, seek_time_us, is_seek_down ? "DOWN" : "UP");
+        uint64_t seek_delay_us = seek_time_us * TIMER_USEC;
+        timer_set_delay_u64(&fdd_seek_timer[drive], seek_delay_us);
     }
 }
 
@@ -430,6 +468,15 @@ fdd_track0(int drive)
     return !fdd[drive].track;
 }
 
+int
+fdd_get_type_max_track(int type)
+{
+    if (type < 0 || type >= (sizeof(drive_types) / sizeof(drive_types[0])))
+        return 0;
+
+    return drive_types[type].max_track;
+}
+
 int
 fdd_current_track(int drive)
 {
@@ -677,6 +724,7 @@ fdd_close(int drive)
     drives[drive].format        = NULL;
     drives[drive].byteperiod    = NULL;
     drives[drive].stop          = NULL;
+    fdd_seek_in_progress[drive] = 0;
     d86f_destroy(drive);
     ui_sb_update_icon_state(SB_FLOPPY | drive, 1);
 }
@@ -765,9 +813,15 @@ fdd_get_bitcell_period(int rate)
 void
 fdd_reset(void)
 {
+    /* Reset boot status to POST on system reset */
+    fdd_boot_status_reset();
+
     for (uint8_t i = 0; i < FDD_NUM; i++) {
         drives[i].id = i;
         timer_add(&(fdd_poll_time[i]), fdd_poll, &drives[i], 0);
+
+        /* Clear any pending seek state */
+        fdd_seek_in_progress[i] = 0;
     }
 }
 
@@ -776,6 +830,11 @@ fdd_readsector(int drive, int sector, int track, int side, int density, int sect
 {
     fdd_log("fdd_readsector(%d, %d, %d, %d, %d, %d)\n", drive, sector, track, side, density, sector_size);
 
+    /* First floppy read operation marks POST as complete */
+    if (bios_boot_status == BIOS_BOOT_POST) {
+        fdd_set_boot_status(BIOS_BOOT_NORMAL);
+    }
+
     if (fdd_seek_in_progress[drive]) {
         fdd_log("Seek in progress on drive %d, deferring READ (trk=%d->%d, side=%d, sec=%d)\n",
                 drive, fdd[drive].track, track, side, sector);
