@@ -88,27 +88,52 @@ static const joystick_t joystick_none = {
 static const struct {
     const joystick_t *joystick;
 } joysticks[] = {
-    { &joystick_none                         },
-    { &joystick_2axis_2button                },
-    { &joystick_2button_gamepad              },
-    { &joystick_2button_flight_yoke          },
-    { &joystick_2axis_4button                },
-    { &joystick_4button_gamepad              },
-    { &joystick_4button_flight_yoke          },
-    { &joystick_2axis_6button                },
-    { &joystick_2axis_8button                },
-    { &joystick_3axis_2button                },
-    { &joystick_2button_yoke_throttle        },
-    { &joystick_3axis_4button                },
-    { &joystick_win95_steering_wheel         },
-    { &joystick_4button_yoke_throttle        },
-    { &joystick_4axis_4button                },
-    { &joystick_ch_flightstick_pro           },
-    { &joystick_ch_flightstick_pro_ch_pedals },
-    { &joystick_sw_pad                       },
-    { &joystick_tm_fcs                       },
-    { &joystick_tm_fcs_rcs                   },
-    { NULL                                   }
+    { &joystick_none                               },
+    { &joystick_generic_paddle                     },
+    { &joystick_2axis_1button                      },
+    { &joystick_2axis_2button                      },
+    { &joystick_2axis_3button                      },
+    { &joystick_2axis_4button                      },
+    { &joystick_2axis_6button                      },
+    { &joystick_2axis_8button                      },
+    { &joystick_3axis_2button                      },
+    { &joystick_3axis_3button                      },
+    { &joystick_3axis_4button                      },
+    { &joystick_4axis_2button                      },
+    { &joystick_4axis_3button                      },
+    { &joystick_4axis_4button                      },
+    { &joystick_2button_gamepad                    },
+    { &joystick_3button_gamepad                    },
+    { &joystick_4button_gamepad                    },
+    { &joystick_6button_gamepad                    },
+    { &joystick_gravis_gamepad                     },
+    { &joystick_2button_flight_yoke                },
+    { &joystick_3button_flight_yoke                },
+    { &joystick_4button_flight_yoke                },
+    { &joystick_2button_yoke_throttle              },
+    { &joystick_3button_yoke_throttle              },
+    { &joystick_4button_yoke_throttle              },
+    { &joystick_steering_wheel_2_button            },
+    { &joystick_steering_wheel_3_button            },
+    { &joystick_steering_wheel_4_button            },
+    { &joystick_ch_flightstick                     },
+    { &joystick_ch_flightstick_ch_pedals           },
+    { &joystick_ch_flightstick_ch_pedals_pro       },
+    { &joystick_ch_flightstick_pro                 },
+    { &joystick_ch_flightstick_pro_ch_pedals       },
+    { &joystick_ch_flightstick_pro_ch_pedals_pro   },
+    { &joystick_ch_virtual_pilot                   },
+    { &joystick_ch_virtual_pilot_ch_pedals         },
+    { &joystick_ch_virtual_pilot_ch_pedals_pro     },
+    { &joystick_ch_virtual_pilot_pro               },
+    { &joystick_ch_virtual_pilot_pro_ch_pedals     },
+    { &joystick_ch_virtual_pilot_pro_ch_pedals_pro },
+    { &joystick_sw_pad                             },
+    { &joystick_tm_fcs                             },
+    { &joystick_tm_fcs_rcs                         },
+    { &joystick_tm_formula_t1t2                    },
+    { &joystick_tm_formula_t1t2wa                  },
+    { NULL                                         }
 };
 
 static joystick_instance_t *joystick_instance[GAMEPORT_MAX] = { NULL, NULL };
