@@ -8,13 +8,10 @@
  *
  *          Header files for the PCjr keyboard and video subsystems.
  *
- *
- *
  * Authors: Connor Hyde, <mario64crashed@gmail.com>
  *
  *          Copyright 2025 starfrost
  */
-
 #pragma once
 
 #define PCJR_RGB          0
@@ -27,8 +24,7 @@
 #define DOUBLE_INTERPOLATE_SRGB   2
 #define DOUBLE_INTERPOLATE_LINEAR 3
 
-typedef struct pcjr_s 
-{
+typedef struct pcjr_s {
     /* Video Controller stuff. */
     mem_mapping_t mapping;
     uint8_t       crtc[32];
@@ -46,7 +42,7 @@ typedef struct pcjr_s
     int           scanline;
     int           vc;
     int           dispon;
-    int           cursorvisible;            // Is the cursor visible on the current scanline?
+    int           cursorvisible; // Is the cursor visible on the current scanline?
     int           cursoron;
     int           blink;
     int           vsynctime;
@@ -63,13 +59,18 @@ typedef struct pcjr_s
     int           apply_hd;
     int           double_type;
 
-        /* Keyboard Controller stuff. */
+    /* Keyboard Controller stuff. */
     int        latched;
     int        data;
     int        serial_data[44];
     int        serial_pos;
     uint8_t    pa;
     uint8_t    pb;
+
+    uint8_t    option_modem;
+    uint8_t    option_fdc;
+    uint8_t    option_ir;
+
     pc_timer_t send_delay_timer;
 
 } pcjr_t; 
@@ -77,4 +78,4 @@ typedef struct pcjr_s
 void pcjr_recalc_timings(pcjr_t *pcjr);
 
 // Note: This is a temporary solution until the pcjr video is made its own gfx card
-void pcjr_vid_init(pcjr_t *pcjr);
\ No newline at end of file
+void pcjr_vid_init(pcjr_t *pcjr);
