@@ -8,8 +8,6 @@
  *
  *          Generic SVGA handling.
  *
- *
- *
  * Authors: Sarah Walker, <https://pcem-emulator.co.uk/>
  *          Miran Grca, <mgrca8@gmail.com>
  *
@@ -31,6 +29,7 @@
 #    define FLAG_512K_MASK    512
 #    define FLAG_NO_SHIFT3    1024 /* Needed for Bochs VBE. */
 #    define FLAG_PRECISETIME  2048 /* Needed for Copper demo if on dynarec. */
+#    define FLAG_PANNING_ATI  4096
 struct monitor_t;
 
 typedef struct hwcursor_t {
@@ -138,9 +137,14 @@ typedef struct svga_t {
     int ps_bit_bug;
     int ati_4color;
     int vblankend;
+    int panning_blank;
     int render_line_offset;
     int start_retrace_latch;
     int vga_mode;
+    int half_pixel;
+    int clock_multiplier;
+    int true_color_bypass;
+    int multiplexing_rate;
 
     /*The three variables below allow us to implement memory maps like that seen on a 1MB Trio64 :
       0MB-1MB - VRAM
@@ -444,16 +448,26 @@ extern void    ibm_rgb528_ramdac_out(uint16_t addr, int rs2, uint8_t val, void *
 extern uint8_t ibm_rgb528_ramdac_in(uint16_t addr, int rs2, void *priv, svga_t *svga);
 extern void    ibm_rgb528_recalctimings(void *priv, svga_t *svga);
 extern void    ibm_rgb528_hwcursor_draw(svga_t *svga, int displine);
+extern float   ibm_rgb528_getclock(int clock, void *priv);
+extern void    ibm_rgb528_ramdac_set_ref_clock(void *priv, svga_t *svga, float ref_clock);
+
+extern float icd2047_getclock(int clock, void *priv);
 
 extern void  icd2061_write(void *priv, int val);
 extern float icd2061_getclock(int clock, void *priv);
+extern void  icd2061_set_ref_clock(void *priv, float ref_clock);
 
 /* The code is the same, the #define's are so that the correct name can be used. */
 #    define ics9161_write    icd2061_write
 #    define ics9161_getclock icd2061_getclock
 
+extern float ics1494_getclock(int clock, void *priv);
+
 extern float ics2494_getclock(int clock, void *priv);
 
+extern float ics90c64a_vclk_getclock(int clock, void *priv);
+extern float ics90c64a_mclk_getclock(int clock, void *priv);
+
 extern void   ics2595_write(void *priv, int strobe, int dat);
 extern double ics2595_getclock(void *priv);
 extern void   ics2595_setclock(void *priv, double clock);
@@ -463,10 +477,13 @@ extern uint8_t sc1148x_ramdac_in(uint16_t addr, int rs2, void *priv, svga_t *svg
 
 extern void    sc1502x_ramdac_out(uint16_t addr, uint8_t val, void *priv, svga_t *svga);
 extern uint8_t sc1502x_ramdac_in(uint16_t addr, void *priv, svga_t *svga);
+extern void    sc1502x_rs2_ramdac_out(uint16_t addr, int rs2, uint8_t val, void *priv, svga_t *svga);
+extern uint8_t sc1502x_rs2_ramdac_in(uint16_t addr, int rs2, void *priv, svga_t *svga);
 
 extern void    sdac_ramdac_out(uint16_t addr, int rs2, uint8_t val, void *priv, svga_t *svga);
 extern uint8_t sdac_ramdac_in(uint16_t addr, int rs2, void *priv, svga_t *svga);
 extern float   sdac_getclock(int clock, void *priv);
+extern void    sdac_set_ref_clock(void *priv, float ref_clock);
 
 extern void    stg_ramdac_out(uint16_t addr, uint8_t val, void *priv, svga_t *svga);
 extern uint8_t stg_ramdac_in(uint16_t addr, void *priv, svga_t *svga);
@@ -499,7 +516,10 @@ extern const device_t att20c505_ramdac_device;
 extern const device_t bt485a_ramdac_device;
 extern const device_t gendac_ramdac_device;
 extern const device_t ibm_rgb528_ramdac_device;
+extern const device_t ics1494m_540_device;
+extern const device_t ics1494m_540_radius_ht209_device;
 extern const device_t ics2494an_305_device;
+extern const device_t ics2494an_324_device;
 extern const device_t ati18810_28800_device;
 extern const device_t ati18811_0_28800_device;
 extern const device_t ati18811_1_28800_device;
@@ -507,15 +527,19 @@ extern const device_t ati18810_mach32_device;
 extern const device_t ati18811_0_mach32_device;
 extern const device_t ati18811_1_mach32_device;
 extern const device_t ics2595_device;
+extern const device_t icd2047_20_device;
 extern const device_t icd2061_device;
+extern const device_t ics90c64a_903_device;
 extern const device_t ics9161_device;
 extern const device_t sc11483_ramdac_device;
 extern const device_t sc11487_ramdac_device;
 extern const device_t sc11486_ramdac_device;
 extern const device_t sc11484_nors2_ramdac_device;
 extern const device_t sc1502x_ramdac_device;
+extern const device_t sc1502x_rs2_ramdac_device;
 extern const device_t sdac_ramdac_device;
-extern const device_t stg_ramdac_device;
+extern const device_t stg1702_ramdac_device;
+extern const device_t stg1703_ramdac_device;
 extern const device_t tkd8001_ramdac_device;
 extern const device_t tseng_ics5301_ramdac_device;
 extern const device_t tseng_ics5341_ramdac_device;
