@@ -37,6 +37,7 @@
 #include <86box/serial.h>
 #include <86box/sio.h>
 #include <86box/ibm_5161.h>
+#include <86box/isartc.h>
 #include <86box/keyboard.h>
 #include <86box/rom.h>
 #include <86box/machine.h>
@@ -45,9 +46,6 @@
 #include <86box/port_6x.h>
 #include <86box/video.h>
 
-extern const device_t vendex_xt_rtc_onboard_device;
-extern const device_t rtc58167_device;
-
 /* 8088 */
 static void
 machine_xt_common_init(const machine_t *model, int fixed_floppy)
@@ -1251,7 +1249,7 @@ static const device_config_t pc500_config[] = {
         .spinner        = { 0 },
         .selection      = {
             { .description = "Disabled", .value = -1 },
-            { .description = "Enabled",  .value =  2 },
+            { .description = "IRQ 2",    .value =  2 },
             { .description = ""                      }
         },
         .bios           = { { 0 } }
@@ -1259,7 +1257,7 @@ static const device_config_t pc500_config[] = {
     {
         .name           = "rtc_port",
         .description    = "RTC Port Address",
-        .type           = CONFIG_HEX16,
+        .type           = CONFIG_SELECTION,
         .default_string = NULL,
         .default_int    = 0,
         .file_filter    = NULL,
@@ -1310,7 +1308,7 @@ machine_xt_pc500_init(const machine_t *model)
     if (bios_only || !ret)
         return ret;
 
-    device_add(&kbc_xtclone_device);
+    device_add(&kbc_pc82_device);
 
     machine_xt_common_init(model, 0);
 
@@ -1371,7 +1369,7 @@ static const device_config_t pc500plus_config[] = {
         .spinner        = { 0 },
         .selection      = {
             { .description = "Disabled", .value = -1 },
-            { .description = "Enabled",  .value =  2 },
+            { .description = "IRQ 2",    .value =  2 },
             { .description = ""                      }
         },
         .bios           = { { 0 } }
@@ -1379,7 +1377,7 @@ static const device_config_t pc500plus_config[] = {
     {
         .name           = "rtc_port",
         .description    = "Onboard RTC",
-        .type           = CONFIG_HEX16,
+        .type           = CONFIG_SELECTION,
         .default_string = NULL,
         .default_int    = 0,
         .file_filter    = NULL,
@@ -1429,9 +1427,7 @@ machine_xt_pc500plus_init(const machine_t *model)
     if (bios_only || !ret)
         return ret;
 
-    device_add(&kbc_xtclone_device);
-
-    machine_xt_common_init(model, 0);
+    machine_xt_clone_init(model, 0);
 
     if (rtc_port != 0)
         device_add(&rtc58167_device);
@@ -1507,7 +1503,7 @@ machine_xt_pc700_init(const machine_t *model)
     if (bios_only || !ret)
         return ret;
 
-    device_add(&kbc_pc_device);
+    device_add(&kbc_pc82_device);
 
     machine_xt_common_init(model, 0);
 
@@ -1706,6 +1702,79 @@ machine_xt_pcxt_init(const machine_t *model)
     return ret;
 }
 
+static const device_config_t to16_config[] = {
+    // clang-format off
+    {
+        .name           = "rtc_port",
+        .description    = "Onboard RTC",
+        .type           = CONFIG_SELECTION,
+        .default_string = NULL,
+        .default_int    = 0,
+        .file_filter    = NULL,
+        .spinner        = { 0 },
+        .selection      = {
+            { .description = "Not installed", .value =     0 },
+            { .description = "RTC0",          .value = 0x300 },
+            { .description = "RTC1",          .value = 0x2c0 },
+            { .description = ""                              }
+        },
+        .bios           = { { 0 } }
+    },
+    {
+        .name           = "rtc_irq",
+        .description    = "RTC IRQ",
+        .type           = CONFIG_SELECTION,
+        .default_string = NULL,
+        .default_int    = -1,
+        .file_filter    = NULL,
+        .spinner        = { 0 },
+        .selection      = {
+            { .description = "Disabled", .value = -1 },
+            { .description = "IRQ 2",    .value =  2 },
+            { .description = ""                      }
+        },
+        .bios           = { { 0 } }
+    },
+    { .name = "", .description = "", .type = CONFIG_END }
+    // clang-format on
+};
+
+const device_t to16_device = {
+    .name          = "Thomson TO16",
+    .internal_name = "to16_device",
+    .flags         = 0,
+    .local         = 0,
+    .init          = NULL,
+    .close         = NULL,
+    .reset         = NULL,
+    .available     = NULL,
+    .speed_changed = NULL,
+    .force_redraw  = NULL,
+    .config        = to16_config
+};
+
+int
+machine_xt_to16_init(const machine_t *model)
+{
+    int ret;
+
+    ret = bios_load_linear("roms/machines/to16/TO16_103.bin", 0x000f8000, 32768, 0);
+
+    if (bios_only || !ret)
+        return ret;
+
+    device_context(model->device);
+    int rtc_port = machine_get_config_int("rtc_port");
+    device_context_restore();
+
+    machine_xt_clone_init(model, 0);
+
+    if (rtc_port != 0)
+        device_add(&rtc58167_device);
+
+    return ret;
+}
+
 static const device_config_t vendex_config[] = {
     // clang-format off
     {
@@ -2085,7 +2154,7 @@ machine_xt_maz1016_init(const machine_t *model)
     if (bios_only || !ret)
         return ret;
 
-    loadfont("roms/machines/maz1016/crt-8.bin", 0);
+    video_load_font("roms/machines/maz1016/crt-8.bin", FONT_FORMAT_MDA, LOAD_FONT_NO_OFFSET);
 
     machine_xt_clone_init(model, 0);
 
