@@ -8,8 +8,6 @@
  *
  *          Emulation of SPD (Serial Presence Detect) devices.
  *
- *
- *
  * Authors: RichardG, <richardg867@gmail.com>
  *
  *          Copyright 2020 RichardG.
@@ -221,8 +219,7 @@ spd_register(uint8_t ram_type, uint8_t slot_mask, uint16_t max_module_size)
         if (!(slot_mask & (1 << slot)))
             continue; /* slot disabled */
 
-        spd_modules[slot] = (spd_t *) malloc(sizeof(spd_t));
-        memset(spd_modules[slot], 0, sizeof(spd_t));
+        spd_modules[slot] = (spd_t *) calloc(1, sizeof(spd_t));
         spd_modules[slot]->slot = slot;
         spd_modules[slot]->size = rows[row];
 
@@ -595,7 +592,7 @@ static const device_t spd_device = {
     .init          = spd_init,
     .close         = spd_close,
     .reset         = NULL,
-    { .available = NULL },
+    .available     = NULL,
     .speed_changed = NULL,
     .force_redraw  = NULL,
     .config        = NULL
