@@ -30,7 +30,8 @@ SoftwareRenderer::SoftwareRenderer(QWidget *parent)
 #ifdef __HAIKU__
     : QWidget(parent)
 #else
-    : QWindow(parent->windowHandle()), m_backingStore(new QBackingStore(this))
+    : QWindow(parent->windowHandle())
+    , m_backingStore(new QBackingStore(this))
 #endif
 {
     RendererCommon::parentWidget = parent;
@@ -72,7 +73,7 @@ SoftwareRenderer::render()
 }
 
 void
-SoftwareRenderer::exposeEvent(QExposeEvent* event)
+SoftwareRenderer::exposeEvent(QExposeEvent *event)
 {
     render();
 }
@@ -81,7 +82,7 @@ void
 SoftwareRenderer::onBlit(int buf_idx, int x, int y, int w, int h)
 {
     /* TODO: should look into deleteLater() */
-    auto  tval    = this;
+    auto tval = this;
     if ((void *) tval == nullptr)
         return;
     auto origSource = source;
