@@ -153,10 +153,8 @@ plat_mouse_capture(int on)
 int
 ui_msgbox_header(int flags, void *header, void *message)
 {
-    const auto hdr = (flags & MBX_ANSI) ? QString(static_cast<char *>(header)) :
-                            QString::fromWCharArray(static_cast<const wchar_t *>(header));
-    const auto msg = (flags & MBX_ANSI) ? QString(static_cast<char *>(message)) :
-                            QString::fromWCharArray(static_cast<const wchar_t *>(message));
+    const auto hdr = (flags & MBX_ANSI) ? QString(static_cast<char *>(header)) : QString::fromWCharArray(static_cast<const wchar_t *>(header));
+    const auto msg = (flags & MBX_ANSI) ? QString(static_cast<char *>(message)) : QString::fromWCharArray(static_cast<const wchar_t *>(message));
 
     // any error in early init
     if (main_window == nullptr) {
@@ -259,9 +257,9 @@ ui_sb_set_ready(int ready)
 void
 ui_sb_update_icon_wp(int tag, int state)
 {
-    const auto temp    = static_cast<unsigned int>(tag);
-    const int category = static_cast<int>(temp & 0xfffffff0);
-    const int item     = tag & 0xf;
+    const auto temp     = static_cast<unsigned int>(tag);
+    const int  category = static_cast<int>(temp & 0xfffffff0);
+    const int  item     = tag & 0xf;
 
     switch (category) {
         default:
@@ -287,9 +285,9 @@ ui_sb_update_icon_wp(int tag, int state)
 void
 ui_sb_update_icon_state(int tag, int state)
 {
-    const auto temp    = static_cast<unsigned int>(tag);
-    const int category = static_cast<int>(temp & 0xfffffff0);
-    const int item     = tag & 0xf;
+    const auto temp     = static_cast<unsigned int>(tag);
+    const int  category = static_cast<int>(temp & 0xfffffff0);
+    const int  item     = tag & 0xf;
 
     switch (category) {
         default:
@@ -329,9 +327,9 @@ ui_sb_update_icon_state(int tag, int state)
 void
 ui_sb_update_icon(int tag, int active)
 {
-    const auto temp    = static_cast<unsigned int>(tag);
-    const int category = static_cast<int>(temp & 0xfffffff0);
-    const int item     = tag & 0xf;
+    const auto temp     = static_cast<unsigned int>(tag);
+    const int  category = static_cast<int>(temp & 0xfffffff0);
+    const int  item     = tag & 0xf;
 
     switch (category) {
         default:
@@ -365,9 +363,9 @@ ui_sb_update_icon(int tag, int active)
 void
 ui_sb_update_icon_write(int tag, int write)
 {
-    const auto temp    = static_cast<unsigned int>(tag);
-    const int category = static_cast<int>(temp & 0xfffffff0);
-    const int item     = tag & 0xf;
+    const auto temp     = static_cast<unsigned int>(tag);
+    const int  category = static_cast<int>(temp & 0xfffffff0);
+    const int  item     = tag & 0xf;
 
     switch (category) {
         default:
@@ -397,5 +395,4 @@ ui_sb_update_icon_write(int tag, int write)
             break;
     }
 }
-
 }
