@@ -18,13 +18,23 @@
 
 extern "C" {
 #include <86box/plat.h>
+#include <86box/version.h>
 }
 
-VMManagerConfig::VMManagerConfig(const ConfigType type, const QString& section)
+QVariantHash VMManagerConfig::generalDefaults = {
+    { "hide_tool_bar",   0 },
+    { "regex_search",    0 },
+#if EMU_BUILD_NUM != 0
+    { "update_check",    1 },
+#endif
+    { "window_remember", 0 }
+};
+
+VMManagerConfig::VMManagerConfig(const ConfigType type, const QString &section)
 {
     char BUF[256];
     plat_get_global_config_dir(BUF, 255);
-    const auto configDir = QString(BUF);
+    const auto configDir  = QString(BUF);
     const auto configFile = QDir::cleanPath(configDir + "/" + "vmm.ini");
 
     config_type = type;
@@ -34,19 +44,25 @@ VMManagerConfig::VMManagerConfig(const ConfigType type, const QString& section)
     settings->setIniCodec("UTF-8");
 #endif
     settings->setFallbacksEnabled(false);
-    if(type == ConfigType::System && !section.isEmpty()) {
+    if (type == ConfigType::System && !section.isEmpty()) {
         settings->beginGroup(section);
+    } else {
+        settings->beginGroup("");
     }
 }
 
-VMManagerConfig::~VMManagerConfig() {
+VMManagerConfig::~VMManagerConfig()
+{
     settings->endGroup();
 }
 
 QString
-VMManagerConfig::getStringValue(const QString& key) const
+VMManagerConfig::getStringValue(const QString &key) const
 {
-    const auto value = settings->value(key);
+    auto defaultValue = QVariant();
+    if ((config_type == ConfigType::General) && (generalDefaults.contains(key)))
+        defaultValue = generalDefaults[key];
+    const auto value = settings->value(key, defaultValue);
     // An invalid QVariant with toString will give a default QString value which is blank.
     // Therefore any variables that do not exist will return blank strings
     return value.toString();
@@ -73,4 +89,3 @@ VMManagerConfig::sync() const
 {
     settings->sync();
 }
-
