@@ -25,8 +25,7 @@ namespace Ui {
 class VMManagerMainWindow;
 }
 
-class VMManagerMainWindow final : public QMainWindow
-{
+class VMManagerMainWindow final : public QMainWindow {
     Q_OBJECT
 public:
     explicit VMManagerMainWindow(QWidget *parent = nullptr);
@@ -41,10 +40,14 @@ signals:
 
 private:
     Ui::VMManagerMainWindow *ui;
+
     VMManagerMain *vmm;
-    void saveSettings() const;
-    QLabel *statusLeft;
-    QLabel *statusRight;
+    void           saveSettings() const;
+    QLabel        *statusLeft;
+    QLabel        *statusRight;
+    QIcon          runIcon;
+    QIcon          pauseIcon;
+
 public slots:
     void setStatusLeft(const QString &text) const;
     void setStatusRight(const QString &text) const;
@@ -54,7 +57,8 @@ public slots:
 #endif
 
 private slots:
-    void vmmSelectionChanged(const QModelIndex &currentSelection, QProcess::ProcessState processState) const;
+    void vmmStateChanged(const VMManagerSystem *sysconfig) const;
+    void on_actionHide_tool_bar_triggered();
     void preferencesTriggered();
 #if EMU_BUILD_NUM != 0
     void checkForUpdatesTriggered();
