@@ -15,28 +15,32 @@
 #include <QDebug>
 #include "qt_vmmanager_model.hpp"
 
-VMManagerModel::VMManagerModel() {
+VMManagerModel::VMManagerModel()
+{
     auto machines_vec = VMManagerSystem::scanForConfigs();
-    for ( const auto& each_config : machines_vec) {
+    for (const auto &each_config : machines_vec) {
         machines.append(each_config);
         connect(each_config, &VMManagerSystem::itemDataChanged, this, &VMManagerModel::modelDataChanged);
         connect(each_config, &VMManagerSystem::globalConfigurationChanged, this, &VMManagerModel::globalConfigurationChanged);
     }
 }
 
-VMManagerModel::~VMManagerModel() {
-    for ( auto machine : machines) {
+VMManagerModel::~VMManagerModel()
+{
+    for (auto machine : machines) {
         delete machine;
     }
 }
 
 int
-VMManagerModel::rowCount(const QModelIndex &parent) const {
+VMManagerModel::rowCount(const QModelIndex &parent) const
+{
     return machines.size();
 }
 
 QVariant
-VMManagerModel::data(const QModelIndex &index, int role) const {
+VMManagerModel::data(const QModelIndex &index, int role) const
+{
     if (!index.isValid())
         return {};
 
@@ -76,7 +80,8 @@ VMManagerModel::data(const QModelIndex &index, int role) const {
 }
 
 QVariant
-VMManagerModel::headerData(int section, Qt::Orientation orientation, int role) const {
+VMManagerModel::headerData(int section, Qt::Orientation orientation, int role) const
+{
 
     if (role != Qt::DisplayRole)
         return {};
@@ -93,7 +98,7 @@ VMManagerModel::getConfigObjectForIndex(const QModelIndex &index) const
     return machines.at(index.row());
 }
 void
-VMManagerModel::reload(QWidget* parent)
+VMManagerModel::reload(QWidget *parent)
 {
     // Scan for configs
     auto machines_vec = VMManagerSystem::scanForConfigs(parent);
@@ -112,16 +117,17 @@ VMManagerModel::reload(QWidget* parent)
 }
 
 void
-VMManagerModel::refreshConfigs() {
-    for ( const auto& each_config : machines)
+VMManagerModel::refreshConfigs()
+{
+    for (const auto &each_config : machines)
         each_config->reloadConfig();
 }
 
 QModelIndex
-VMManagerModel::getIndexForConfigFile(const QFileInfo& config_file)
+VMManagerModel::getIndexForConfigFile(const QFileInfo &config_file)
 {
     int object_index = 0;
-    for (const auto& config_object: machines) {
+    for (const auto &config_object : machines) {
         if (config_object->config_file == config_file) {
             return this->index(object_index);
         }
@@ -155,7 +161,7 @@ void
 VMManagerModel::modelDataChanged()
 {
     // Inform the model
-    emit dataChanged(this->index(0), this->index(machines.size()-1));
+    emit dataChanged(this->index(0), this->index(machines.size() - 1));
     // Inform any interested observers
     emit systemDataChanged();
 }
@@ -170,7 +176,7 @@ QMap<VMManagerSystem::ProcessStatus, int>
 VMManagerModel::getProcessStats()
 {
     QMap<VMManagerSystem::ProcessStatus, int> stats;
-    for (const auto& system: machines) {
+    for (const auto &system : machines) {
         stats[system->getProcessStatus()] += 1;
     }
     return stats;
@@ -179,7 +185,7 @@ VMManagerModel::getProcessStats()
 void
 VMManagerModel::sendGlobalConfigurationChanged()
 {
-    for (auto& system: machines) {
+    for (auto &system : machines) {
         if (system->getProcessStatus() != VMManagerSystem::ProcessStatus::Stopped) {
             system->sendGlobalConfigurationChanged();
         }
@@ -190,7 +196,7 @@ int
 VMManagerModel::getActiveMachineCount()
 {
     int running = 0;
-    for (const auto& system: machines) {
+    for (const auto &system : machines) {
         if (system->getProcessStatus() != VMManagerSystem::ProcessStatus::Stopped)
             running++;
     }
