@@ -22,12 +22,12 @@ VMManagerProtocol::VMManagerProtocol(VMManagerProtocol::Sender sender)
 }
 
 VMManagerProtocol::~VMManagerProtocol()
-= default;
+    = default;
 
 QJsonObject
 VMManagerProtocol::protocolManagerMessage(VMManagerProtocol::ManagerMessage message_type)
 {
-    auto json_message = constructDefaultObject(VMManagerProtocol::Sender::Manager);
+    auto json_message       = constructDefaultObject(VMManagerProtocol::Sender::Manager);
     json_message["message"] = managerMessageTypeToString(message_type);
     return json_message;
 }
@@ -35,7 +35,7 @@ VMManagerProtocol::protocolManagerMessage(VMManagerProtocol::ManagerMessage mess
 QJsonObject
 VMManagerProtocol::protocolClientMessage(VMManagerProtocol::ClientMessage message_type)
 {
-    auto json_message = constructDefaultObject(VMManagerProtocol::Sender::Client);
+    auto json_message       = constructDefaultObject(VMManagerProtocol::Sender::Client);
     json_message["message"] = clientMessageTypeToString(message_type);
     return json_message;
 }
@@ -58,16 +58,16 @@ QJsonObject
 VMManagerProtocol::constructDefaultObject(VMManagerProtocol::Sender type)
 {
     QJsonObject json_message;
-    QString sender_type = ( type == VMManagerProtocol::Sender::Client ) ? "Client" : "VMManager";
-    json_message["type"] = QString(sender_type);
+    QString     sender_type = (type == VMManagerProtocol::Sender::Client) ? "Client" : "VMManager";
+    json_message["type"]    = QString(sender_type);
     json_message["version"] = QStringLiteral(EMU_VERSION);
     return json_message;
 }
 
 bool
-VMManagerProtocol::hasRequiredFields(const QJsonObject& json_document)
+VMManagerProtocol::hasRequiredFields(const QJsonObject &json_document)
 {
-    for (const auto& field : ProtocolRequiredFields) {
+    for (const auto &field : ProtocolRequiredFields) {
         if (!json_document.contains(field)) {
             qDebug("Received json missing field \"%s\"", qPrintable(field));
             return false;
@@ -83,21 +83,21 @@ VMManagerProtocol::getClientMessageType(const QJsonObject &json_document)
     // required values.
     QString message_type = json_document.value("message").toString();
     // Can't use switch with strings, manual compare
-    if (message_type == "Status") {
+    if (message_type == "Status")
         return VMManagerProtocol::ClientMessage::Status;
-    } else if (message_type == "WindowBlocked") {
+    else if (message_type == "WindowBlocked")
         return VMManagerProtocol::ClientMessage::WindowBlocked;
-    } else if (message_type == "WindowUnblocked") {
+    else if (message_type == "WindowUnblocked")
         return VMManagerProtocol::ClientMessage::WindowUnblocked;
-    } else if (message_type == "RunningStateChanged") {
+    else if (message_type == "RunningStateChanged")
         return VMManagerProtocol::ClientMessage::RunningStateChanged;
-    } else if (message_type == "ConfigurationChanged") {
+    else if (message_type == "ConfigurationChanged")
         return VMManagerProtocol::ClientMessage::ConfigurationChanged;
-    } else if (message_type == "WinIdMessage") {
+    else if (message_type == "WinIdMessage")
         return VMManagerProtocol::ClientMessage::WinIdMessage;
-    } else if (message_type == "GlobalConfigurationChanged") {
+    else if (message_type == "GlobalConfigurationChanged")
         return VMManagerProtocol::ClientMessage::GlobalConfigurationChanged;
-    }
+
     return VMManagerProtocol::ClientMessage::UnknownMessage;
 }
 
@@ -108,23 +108,29 @@ VMManagerProtocol::getManagerMessageType(const QJsonObject &json_document)
     // required values.
     QString message_type = json_document.value("message").toString();
     // Can't use switch with strings, manual compare
-    if (message_type == "RequestStatus") {
+    if (message_type == "RequestStatus")
         return VMManagerProtocol::ManagerMessage::RequestStatus;
-    } else if (message_type == "Pause") {
+    else if (message_type == "Pause")
         return VMManagerProtocol::ManagerMessage::Pause;
-    } if (message_type == "CtrlAltDel") {
+
+    if (message_type == "CtrlAltDel")
         return VMManagerProtocol::ManagerMessage::CtrlAltDel;
-    } if (message_type == "ShowSettings") {
+
+    if (message_type == "ShowSettings")
         return VMManagerProtocol::ManagerMessage::ShowSettings;
-    } if (message_type == "ResetVM") {
+
+    if (message_type == "ResetVM")
         return VMManagerProtocol::ManagerMessage::ResetVM;
-    } if (message_type == "RequestShutdown") {
+
+    if (message_type == "RequestShutdown")
         return VMManagerProtocol::ManagerMessage::RequestShutdown;
-    } if (message_type == "ForceShutdown") {
+
+    if (message_type == "ForceShutdown")
         return VMManagerProtocol::ManagerMessage::ForceShutdown;
-    } if (message_type == "GlobalConfigurationChanged") {
+
+    if (message_type == "GlobalConfigurationChanged")
         return VMManagerProtocol::ManagerMessage::GlobalConfigurationChanged;
-    }
+
     return VMManagerProtocol::ManagerMessage::UnknownMessage;
 }
 
@@ -134,8 +140,8 @@ VMManagerProtocol::getParams(const QJsonObject &json_document)
     // FIXME: This key ("params") is hardcoded here. Make a hash which maps these
     // required values.
     auto params_object = json_document.value("params");
-    if (params_object.type() != QJsonValue::Object) {
+    if (params_object.type() != QJsonValue::Object)
         return {};
-    }
+
     return params_object.toObject();
 }
