@@ -24,17 +24,17 @@
 
 // This macro helps give us the required `qHash()` function in order to use the
 // enum as a hash key
-#define QHASH_FOR_CLASS_ENUM(T) \
-inline uint qHash(const T &t, uint seed) { \
-    return ::qHash(static_cast<typename std::underlying_type<T>::type>(t), seed); \
-}
+#define QHASH_FOR_CLASS_ENUM(T)                                                       \
+    inline uint qHash(const T &t, uint seed)                                          \
+    {                                                                                 \
+        return ::qHash(static_cast<typename std::underlying_type<T>::type>(t), seed); \
+    }
 
 class VMManagerServerSocket : public QWidget {
 
     Q_OBJECT
 
 public:
-
     enum class ServerType {
         Standard,
         Legacy,
@@ -53,16 +53,16 @@ public:
     QLocalServer *server;
     QLocalSocket *socket;
     ServerType    server_type;
-    bool serverIsRunning;
+    bool          serverIsRunning;
 
     // Server functions
-    bool startServer();
-    void serverConnectionReceived();
-    void serverReceivedMessage();
-    void serverSendMessage(VMManagerProtocol::ManagerMessage protocol_message, const QStringList& arguments = QStringList()) const;
+    bool        startServer();
+    void        serverConnectionReceived();
+    void        serverReceivedMessage();
+    void        serverSendMessage(VMManagerProtocol::ManagerMessage protocol_message, const QStringList &arguments = QStringList()) const;
     static void serverDisconnected();
-    void jsonReceived(const QJsonObject &json);
-    QString getSocketPath() const;
+    void        jsonReceived(const QJsonObject &json);
+    QString     getSocketPath() const;
 
     static QString serverTypeToString(ServerType server_type_lookup);
 
@@ -75,8 +75,6 @@ signals:
     void configurationChanged();
     void globalConfigurationChanged();
     void winIdReceived(WId id);
-
-
 };
 
 #endif // QT_VMMANAGER_SERVERSOCKET_H
