@@ -327,8 +327,10 @@ video_prepare(void)
 
     for (int i = 0; i < MONITORS_NUM; i++) {
         /* Reset the CGA palette. */
+#if 0
         if (monitors[i].mon_cga_palette)
             *monitors[i].mon_cga_palette = 0;
+#endif
         cgapal_rebuild_monitor(i);
 
         /* Do an inform on the default values, so that that there's some sane values initialized
@@ -358,7 +360,7 @@ video_reset(int card)
                   card, machine_has_flags(machine, MACHINE_VIDEO) ? 1 : 0);
 
     monitor_index_global = 0;
-    loadfont(FONT_IBM_MDA_437_PATH, 0);
+    video_load_font(FONT_IBM_MDA_437_PATH, FONT_FORMAT_MDA, LOAD_FONT_NO_OFFSET);
 
     for (uint8_t i = 1; i < GFXCARD_MAX; i ++) {
         if ((card != VID_NONE) && !machine_has_flags(machine, MACHINE_VIDEO_ONLY) &&
@@ -480,21 +482,3 @@ video_is_cga(void)
 {
     return (video_get_type() == VIDEO_FLAG_TYPE_CGA);
 }
-
-int
-video_is_ega_vga(void)
-{
-    return (video_get_type() == VIDEO_FLAG_TYPE_SPECIAL);
-}
-
-int
-video_is_8514(void)
-{
-    return (video_get_type() == VIDEO_FLAG_TYPE_8514);
-}
-
-int
-video_is_xga(void)
-{
-    return (video_get_type() == VIDEO_FLAG_TYPE_XGA);
-}
