@@ -254,6 +254,19 @@ voodoo_fb_writew(uint32_t addr, uint16_t val, void *priv)
             int      colbfog_g  = 0;
             int      colbfog_b  = 0;
 
+            if (params->fbzMode & FBZ_STIPPLE) {
+                if (params->fbzMode & FBZ_STIPPLE_PATT) {
+                    int index = ((y & 3) << 3) | (~x & 7);
+                    if (!(params->stipple & (1 << index)))
+                        goto skip_pixel;
+                } else {
+                    voodoo->params.stipple = (voodoo->params.stipple << 1) | (voodoo->params.stipple >> 31);
+                    if (!(voodoo->params.stipple & 0x80000000)) {
+                        goto skip_pixel;
+                    }
+                }
+            }
+
             if (params->fbzMode & FBZ_DEPTH_ENABLE) {
                 uint16_t old_depth = *(uint16_t *) (&voodoo->fb_mem[write_addr_aux & voodoo->fb_mask]);
 
@@ -373,7 +386,6 @@ voodoo_fb_writel(uint32_t addr, uint32_t val, void *priv)
             colour_data[0].b = val & 0xff;
             colour_data[0].g = (val >> 8) & 0xff;
             colour_data[0].r = (val >> 16) & 0xff;
-            alpha_data[0]    = 0xff;
             write_mask       = LFB_WRITE_COLOUR;
             addr >>= 1;
             break;
@@ -383,12 +395,14 @@ voodoo_fb_writel(uint32_t addr, uint32_t val, void *priv)
             depth_data[0]  = val >> 16;
             write_mask     = LFB_WRITE_BOTH;
             count          = 1;
+            addr >>= 1;
             break;
         case LFB_FORMAT_DEPTH_RGB555:
             colour_data[0] = argb1555[val & 0xffff];
             depth_data[0]  = val >> 16;
             write_mask     = LFB_WRITE_BOTH;
             count          = 1;
+            addr >>= 1;
             break;
         case LFB_FORMAT_DEPTH_ARGB1555:
             colour_data[0] = argb1555[val & 0xffff];
@@ -396,6 +410,7 @@ voodoo_fb_writel(uint32_t addr, uint32_t val, void *priv)
             depth_data[0]  = val >> 16;
             write_mask     = LFB_WRITE_BOTH;
             count          = 1;
+            addr >>= 1;
             break;
 
         case LFB_FORMAT_DEPTH:
@@ -447,6 +462,19 @@ voodoo_fb_writel(uint32_t addr, uint32_t val, void *priv)
             int      colbfog_g  = 0;
             int      colbfog_b  = 0;
 
+            if (params->fbzMode & FBZ_STIPPLE) {
+                if (params->fbzMode & FBZ_STIPPLE_PATT) {
+                    int index = ((y & 3) << 3) | (~(x + c) & 7);
+                    if (!(params->stipple & (1 << index)))
+                        goto skip_pixel;
+                } else {
+                    voodoo->params.stipple = (voodoo->params.stipple << 1) | (voodoo->params.stipple >> 31);
+                    if (!(voodoo->params.stipple & 0x80000000)) {
+                        goto skip_pixel;
+                    }
+                }
+            }
+
             if (params->fbzMode & FBZ_DEPTH_ENABLE) {
                 uint16_t old_depth = *(uint16_t *) (&voodoo->fb_mem[write_addr_aux & voodoo->fb_mask]);
 
